summaryrefslogtreecommitdiffstats
path: root/chrome/renderer/render_widget.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/renderer/render_widget.h')
-rw-r--r--chrome/renderer/render_widget.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/chrome/renderer/render_widget.h b/chrome/renderer/render_widget.h
index 4153ce0..b0c4b11 100644
--- a/chrome/renderer/render_widget.h
+++ b/chrome/renderer/render_widget.h
@@ -14,6 +14,7 @@
#include "base/ref_counted.h"
#include "base/shared_memory.h"
#include "chrome/common/ipc_channel.h"
+#include "chrome/renderer/render_process.h"
#include "skia/ext/platform_canvas.h"
#include "webkit/glue/webwidget_delegate.h"
@@ -86,10 +87,6 @@ class RenderWidget : public IPC::Channel::Listener,
// Close the underlying WebWidget.
void Close();
- // Get the size of the paint buffer for the given rectangle, rounding up to
- // the allocation granularity of the system.
- static size_t GetPaintBufSize(const gfx::Rect& rect);
-
protected:
// Friend RefCounted so that the dtor can be non-public. Using this class
// without ref-counting is an error.
@@ -192,10 +189,10 @@ class RenderWidget : public IPC::Channel::Listener,
// The size of the RenderWidget.
gfx::Size size_;
- // Shared memory handles that are currently in use to transfer an image to
- // the browser.
- base::SharedMemory* current_paint_buf_;
- base::SharedMemory* current_scroll_buf_;
+ // Transport DIBs that are currently in use to transfer an image to the
+ // browser.
+ TransportDIB* current_paint_buf_;
+ TransportDIB* current_scroll_buf_;
// The smallest bounding rectangle that needs to be re-painted. This is non-
// empty if a paint event is pending.